#############################################################################
#############################################################################
################## Learning and the Diffusion of ############################
############## Regime Contention in the Arab Spring #########################
#############################################################################
############# Published in Research & Politics, 2015 ########################
#############################################################################
###### Justus Bamert, Fabrizio Gilardi and Fabio Wasserfallen ###############
#############################################################################
#############################################################################


rm(list=ls())
library(foreign)
library(arm)
library(texreg)
library(glmmML)

setwd("/Users/.../.../Replication_Archive_Arab_Spring")
data <- read.csv("ASdata.csv")
head(data)
attach(data)



#############################################################################
######################## Main Models in Paper ###############################
#############################################################################


mod.1 <- glm(Imitation17 ~ SuccessG17 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.1)

mod.2 <- glm(Imitation114 ~ SuccessG114 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.2)

mod.3 <- glm(Imitation121 ~ SuccessG121 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.3)

mod.4 <- glm(Imitation128 ~ SuccessG128 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.4)

mod.5 <- glm(Imitation135 ~ SuccessG135 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.5)

screenreg(list(mod.1,mod.2,mod.3,mod.4,mod.5), include.pvalues=TRUE ,stars = c(0.01,0.05,0.1), digits=3)



##################### Simulations and Figure #########################

## Odds ratios

sim.1 <- rnorm(10000, coef(mod.1)[2], vcov(mod.1)[2,2])
odds.1 <- exp(mean(sim.1))
ciinf.1 <- exp(quantile(sim.1, 0.025))
cisup.1 <- exp(quantile(sim.1, 0.975))

sim.2 <- rnorm(10000, coef(mod.2)[2], vcov(mod.2)[2,2])
odds.2 <- exp(mean(sim.2))
ciinf.2 <- exp(quantile(sim.2, 0.025))
cisup.2 <- exp(quantile(sim.2, 0.975))

sim.3 <- rnorm(10000, coef(mod.3)[2], vcov(mod.3)[2,2])
odds.3 <- exp(mean(sim.3))
ciinf.3 <- exp(quantile(sim.3, 0.025))
cisup.3 <- exp(quantile(sim.3, 0.975))

sim.4 <- rnorm(10000, coef(mod.4)[2], vcov(mod.4)[2,2])
odds.4 <- exp(mean(sim.4))
ciinf.4 <- exp(quantile(sim.4, 0.025))
cisup.4 <- exp(quantile(sim.4, 0.975))

sim.5 <- rnorm(10000, coef(mod.5)[2], vcov(mod.5)[2,2])
odds.5 <- exp(mean(sim.5))
ciinf.5 <- exp(quantile(sim.5, 0.025))
cisup.5 <- exp(quantile(sim.5, 0.975))

ci <- c(ciinf.1, ciinf.2, ciinf.3, ciinf.4, ciinf.5)
cs <- c(cisup.1, cisup.2, cisup.3, cisup.4, cisup.5)
odds <- c(odds.1, odds.2, odds.3, odds.4, odds.5)

xx <- seq(1,5)

#pdf(file="odds.pdf", paper="special", width=7, height=5.5)
par(mar=c(3.6,3.5,2,1), mgp=c(2.5,0.8,0), cex.axis=1.2, cex.lab=1.2, font.main=1)
plot(c(0.75, 5.25), c(1, max(c(ci, cs))), type="n", xlab="Time frame", ylab="Odds ratio", axes=F)
axis(1, labels=F)
axis(2, at=c(1,5,10,15,20))
mtext(side=1, text=c("1 week", "2 weeks", "3 weeks", "4 weeks", "5 weeks"), at=seq(1,5), padj=1, cex=1.2)
abline(h=1, lty=2)
points(xx, odds, type="b", cex=1.5)
segments(xx, ci, xx, cs)
legend("topright", pch=c(), legend="Effect of successful protests in j\non likelihood of protest imitation", pt.cex=1.5, cex=1.2, bty="n")
#dev.off()



#############################################################################
############################## Appendix #####################################
#############################################################################

######################### Summary statistics #####################

library(pastecs)
sum(data$Imitation17)
sum(data$Imitation114)
sum(data$Imitation121)
sum(data$Imitation128)
sum(data$Imitation135)

sum(data$SuccessG17)
sum(data$SuccessG114)
sum(data$SuccessG121)
sum(data$SuccessG128)
sum(data$SuccessG135)
sum(data$ARDregime1nyi_Demdummy)

stat.desc(data$Neighbors)
stat.desc(data$RegimePolitydiff)
stat.desc(data$RegimePolitydirdiff)
stat.desc(data$PopulationRatio)
stat.desc(data$PopulationUrban2010diff)
stat.desc(data$Religiondiff)
stat.desc(data$Ethnicdiff)
stat.desc(data$YouthBulgei_x100)
stat.desc(data$GDPCapita2010i_in10k)
stat.desc(data$wbTotalnaturalresourcesrents)



######################### Robustness checks #############################


##### Extended definition of success (including also Bahrain, Lybia and Yemen)

mod.1 <- glm(Imitation17 ~ SuccessExt17 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100 + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.1)

mod.2 <- glm(Imitation114 ~ SuccessExt114 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.2)

mod.3 <- glm(Imitation121 ~ SuccessExt121 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.3)

mod.4 <- glm(Imitation128 ~ SuccessExt128 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.4)

mod.5 <- glm(Imitation135 ~ SuccessExt135 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.5)

screenreg(list(mod.1,mod.2,mod.3,mod.4,mod.5), include.pvalues=TRUE ,stars = c(0.01,0.05,0.1), digits=3)



##### Definition of success (Hussain > 0.8; Egypt, Lybia, Tunisia, and Yemen), coding based on Hussain and Howard 2013

mod.1 <- glm(Imitation17 ~ SuccessHussain1 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100 + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.1)

mod.2 <- glm(Imitation114 ~ SuccessHussain2 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.2)

mod.3 <- glm(Imitation121 ~ SuccessHussain3 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.3)

mod.4 <- glm(Imitation128 ~ SuccessHussain4 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.4)

mod.5 <- glm(Imitation135 ~ SuccessHussain5 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.5)

screenreg(list(mod.1,mod.2,mod.3,mod.4,mod.5), include.pvalues=TRUE ,stars = c(0.01,0.05,0.1), digits=3)



#### Sample minus Iran, Israel and Turkey (Iran=4, Israel=6, Turkey=18)

smallersampledata <- data[which(Countriesi!=4 & Countriesi!=6 & Countriesi!=18 & Countriesj!=4 & Countriesj!=6 & Countriesj!=18),]

mod.1 <- glm(Imitation17 ~ SuccessG17 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data= smallersampledata)
summary(mod.1)

mod.2 <- glm(Imitation114 ~ SuccessG114 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data= smallersampledata)
summary(mod.2)

mod.3 <- glm(Imitation121 ~ SuccessG121 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data= smallersampledata)
summary(mod.3)

mod.4 <- glm(Imitation128 ~ SuccessG128 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data= smallersampledata)
summary(mod.4)

mod.5 <- glm(Imitation135 ~ SuccessG135 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data= smallersampledata)
summary(mod.5)

screenreg(list(mod.1,mod.2,mod.3,mod.4,mod.5), include.pvalues=TRUE ,stars = c(0.01,0.05,0.1), digits=3)



########## Other Regime measures than Polity IV score ##############

### State fargility index instead of Polity iV score

mod.1 <- glm(Imitation17 ~ SuccessG17 + Neighbors + seclegdiff + seclegdirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.1)

mod.2 <- glm(Imitation114 ~ SuccessG114 + Neighbors + seclegdiff + seclegdirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.2)

mod.3 <- glm(Imitation121 ~ SuccessG121 + Neighbors + seclegdiff + seclegdirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.3)

mod.4 <- glm(Imitation128 ~ SuccessG128 + Neighbors + seclegdiff + seclegdirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.4)

mod.5 <- glm(Imitation135 ~ SuccessG135 + Neighbors + seclegdiff + seclegdirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.5)

screenreg(list(mod.1,mod.2,mod.3,mod.4,mod.5), include.pvalues=TRUE ,stars = c(0.01,0.05,0.1), digits=3)



#### Same Regime Type instead of Polity IV score

mod.1 <- glm(Imitation17 ~ SuccessG17 + Neighbors + ARDregimediff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.1)

mod.2 <- glm(Imitation114 ~ SuccessG114 + Neighbors + ARDregimediff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.2)

mod.3 <- glm(Imitation121 ~ SuccessG121 + Neighbors + ARDregimediff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy +  wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.3)

mod.4 <- glm(Imitation128 ~ SuccessG128 + Neighbors + ARDregimediff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.4)

mod.5 <- glm(Imitation135 ~ SuccessG135 + Neighbors + ARDregimediff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + YouthBulgei_x100  + GDPCapita2010i_in10k + ARDregime1nyi_Demdummy + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.5)

screenreg(list(mod.1,mod.2,mod.3,mod.4,mod.5), include.pvalues=TRUE ,stars = c(0.01,0.05,0.1), digits=3)



########### Number of Protests in previous weeks as additional control ############

mod.1 <- glm(Imitation17 ~ SuccessG17 + nrprotests1 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.1)

mod.2 <- glm(Imitation114 ~ SuccessG114 + nrprotests2 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.2)

mod.3 <- glm(Imitation121 ~ SuccessG121 + nrprotests3 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.3)

mod.4 <- glm(Imitation128 ~ SuccessG128 + nrprotests4 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.4)

mod.5 <- glm(Imitation135 ~ SuccessG135 + nrprotests5 + Neighbors + RegimePolitydiff + RegimePolitydirdiff + PopulationRatio + PopulationUrban2010diff + Religiondiff + Ethnicdiff + ARDregime1nyi_Demdummy + YouthBulgei_x100  + GDPCapita2010i_in10k + wbTotalnaturalresourcesrents + t + t2 + t3in1k, family=binomial(link="logit"), data=data)
summary(mod.5)

screenreg(list(mod.1,mod.2,mod.3,mod.4,mod.5), include.pvalues=TRUE ,stars = c(0.01,0.05,0.1), digits=3)



















